@@ -5,6 +5,7 @@ import threading
 from timeit import default_timer
 from typing import TYPE_CHECKING, Any, Dict, NewType, Optional
 
+from afancontrol.configparser import ConfigParserSection
 from afancontrol.logger import logger
 
 if TYPE_CHECKING:
@@ -50,11 +51,22 @@ class ArduinoConnection:
             lambda: _StatusProtocol(self), url=serial_url, baudrate=baudrate
         )
         self._context_manager_depth = 0
-        self._status = None  # type: Optional[Dict[str, Dict[str, int]]]
-        self._status_clock = None  # type: Optional[float]
+        self._status: Optional[Dict[str, Dict[str, int]]] = None
+        self._status_clock: Optional[float] = None
         self._status_lock = threading.Lock()
         self._status_event = threading.Event()
 
+    @classmethod
+    def from_configparser(
+        cls, section: ConfigParserSection[ArduinoName]
+    ) -> "ArduinoConnection":
+        return cls(
+            name=section.name,
+            serial_url=section["serial_url"],
+            baudrate=section.getint("baudrate", fallback=DEFAULT_BAUDRATE),
+            status_ttl=section.getint("status_ttl", fallback=DEFAULT_STATUS_TTL),
+        )
+
     def __eq__(self, other):
         if isinstance(other, type(self)):
             return (
@@ -218,10 +230,10 @@ class _AutoRetriedReaderThread:
     def __init__(self, protocol_factory, **serial_for_url_kwargs) -> None:
         self.protocol_factory = protocol_factory
         self.serial_for_url_kwargs = serial_for_url_kwargs
-        self._reader_thread = None  # type: Optional[ReaderThread]
-        self._transport = None  # type: Optional[ReaderThread]
-        self._watchdog_thread = None  # type: Optional[threading.Thread]
-        self._watchdog_queue = queue.Queue()  # type: queue.Queue[Any]
+        self._reader_thread: Optional[ReaderThread] = None
+        self._transport: Optional[ReaderThread] = None
+        self._watchdog_thread: Optional[threading.Thread] = None
+        self._watchdog_queue: queue.Queue[Any] = queue.Queue()
 
     def __enter__(self):  # reusable
         # TODO ?? maybe clean the _watchdog_queue?
