@@ -1,7 +1,7 @@
 import abc
 import sys
 from time import sleep
-from typing import NamedTuple, Optional
+from typing import Optional
 
 import click
 
@@ -15,9 +15,6 @@ from afancontrol.pwmfan import (
     ArduinoFanPWMRead,
     ArduinoFanPWMWrite,
     ArduinoFanSpeed,
-    BaseFanPWMRead,
-    BaseFanPWMWrite,
-    BaseFanSpeed,
     FanInputDevice,
     FanValue,
     LinuxFanPWMRead,
@@ -25,6 +22,7 @@ from afancontrol.pwmfan import (
     LinuxFanSpeed,
     PWMDevice,
     PWMValue,
+    ReadWriteFan,
 )
 
 # Time to wait before measuring fan speed after setting a PWM value.
@@ -74,15 +72,6 @@ HELP_PWM_STEP_SIZE = (
     "faster."
 )
 
-Fan = NamedTuple(
-    "Fan",
-    [
-        ("fan_speed", BaseFanSpeed),
-        ("pwm_read", BaseFanPWMRead),
-        ("pwm_write", BaseFanPWMWrite),
-    ],
-)
-
 
 @click.command()
 @click.option(
@@ -156,25 +145,24 @@ def fantest(
 ) -> None:
     """The PWM fan testing program.
 
-This program tests how changing the PWM value of a fan affects its speed.
+    This program tests how changing the PWM value of a fan affects its speed.
 
-In the beginning the fan would be stopped (by setting it to a minimum PWM value),
-and then the PWM value would be increased in small steps, while also
-measuring the speed as reported by the fan.
+    In the beginning the fan would be stopped (by setting it to a minimum PWM value),
+    and then the PWM value would be increased in small steps, while also
+    measuring the speed as reported by the fan.
 
-This data would help you to find the effective range of values
-for the `pwm_line_start` and `pwm_line_end` settings where the correlation
-between PWM and fan speed is close to linear. Usually its
-`pwm_line_start = 100` and `pwm_line_end = 240`, but it is individual
-for each fan. The allowed range for a PWM value is from 0 to 255.
+    This data would help you to find the effective range of values
+    for the `pwm_line_start` and `pwm_line_end` settings where the correlation
+    between PWM and fan speed is close to linear. Usually its
+    `pwm_line_start = 100` and `pwm_line_end = 240`, but it is individual
+    for each fan. The allowed range for a PWM value is from 0 to 255.
 
-Note that the fan would be stopped for some time during the test. If you'll
-feel nervous, press Ctrl+C to stop the test and return the fan to full speed.
+    Note that the fan would be stopped for some time during the test. If you'll
+    feel nervous, press Ctrl+C to stop the test and return the fan to full speed.
 
-Before starting the test ensure that no fan control software is currently
-controlling the fan you're going to test.
-
-"""
+    Before starting the test ensure that no fan control software is currently
+    controlling the fan you're going to test.
+    """
     try:
         if fan_type == "linux":
             if not linux_fan_pwm:
@@ -191,7 +179,7 @@ controlling the fan you're going to test.
 
             assert linux_fan_pwm is not None
             assert linux_fan_input is not None
-            fan = Fan(
+            fan = ReadWriteFan(
                 fan_speed=LinuxFanSpeed(FanInputDevice(linux_fan_input)),
                 pwm_read=LinuxFanPWMRead(PWMDevice(linux_fan_pwm)),
                 pwm_write=LinuxFanPWMWrite(PWMDevice(linux_fan_pwm)),
@@ -230,7 +218,7 @@ controlling the fan you're going to test.
             )
             assert arduino_pwm_pin is not None
             assert arduino_tacho_pin is not None
-            fan = Fan(
+            fan = ReadWriteFan(
                 fan_speed=ArduinoFanSpeed(
                     arduino_connection, tacho_pin=ArduinoPin(arduino_tacho_pin)
                 ),
@@ -268,7 +256,7 @@ controlling the fan you're going to test.
 
 
 def run_fantest(
-    fan: Fan, pwm_step_size: PWMValue, output: "MeasurementsOutput"
+    fan: ReadWriteFan, pwm_step_size: PWMValue, output: "MeasurementsOutput"
 ) -> None:
     with fan.fan_speed, fan.pwm_read, fan.pwm_write:
         start = fan.pwm_read.min_pwm
