@@ -1,7 +1,8 @@
 import csv
 import io
 
-from afancontrol.exec import exec_shell_command
+from afancontrol.configparser import ConfigParserSection
+from afancontrol.exec import Programs, exec_shell_command
 from afancontrol.pwmfan.base import BaseFanSpeed, FanValue
 
 # TODO maybe switch to `python3-pyghmi`? although it looks like the current version
@@ -18,6 +19,16 @@ class FreeIPMIFanSpeed(BaseFanSpeed):
         self._ipmi_sensors_bin = ipmi_sensors_bin
         self._ipmi_sensors_extra_args = ipmi_sensors_extra_args
 
+    @classmethod
+    def from_configparser(
+        cls, section: ConfigParserSection, programs: Programs
+    ) -> BaseFanSpeed:
+        return cls(
+            section["name"],
+            ipmi_sensors_bin=programs.ipmi_sensors,
+            ipmi_sensors_extra_args=section.get("ipmi_sensors_extra_args", fallback=""),
+        )
+
     def get_speed(self) -> FanValue:
         out = self._call_ipmi_sensors()
         reader = csv.DictReader(io.StringIO(out))
